==> bitcoin-0.14.1.tar.gz: bitcoin-0.14.1/src/qt/locale/bitcoin_cy.ts <==
<TS language="cy" version="2.1">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Create a new address</source>
        <translation>Creu cyfeiriad newydd</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Newydd</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>Copio'r cyfeiriad sydd wedi'i ddewis i'r clipfwrdd system</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;Copïo</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation>C&amp;au</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation>&amp;Allforio</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Dileu</translation>
    </message>
    </context>
<context>
    <name>AddressTableModel</name>
    </context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Enter passphrase</source>
        <translation>Teipiwch gyfrinymadrodd</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation>Cyfrinymadrodd newydd</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation>Ailadroddwch gyfrinymadrodd newydd</translation>
    </message>
    </context>
<context>
    <name>BanTableModel</name>
    </context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>Synchronizing with network...</source>
        <translation>Cysoni â'r rhwydwaith...</translation>
    </message>
    <message>
        <source>&amp;Overview</source>
        <translation>&amp;Trosolwg</translation>
    </message>
    <message>
        <source>Show general overview of wallet</source>
        <translation>Dangos trosolwg cyffredinol y waled</translation>
    </message>
    <message>
        <source>&amp;Transactions</source>
        <translation>&amp;Trafodion</translation>
    </message>
    <message>
        <source>Browse transaction history</source>
        <translation>Pori hanes trafodion</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>A&amp;llanfa</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation>Gadael rhaglen</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Ynghylch &amp;Qt</translation>
    </message>
    <message>
        <source>&amp;Options...</source>
        <translation>&amp;Opsiynau</translation>
    </message>
    <message>
        <source>&amp;Encrypt Wallet...</source>
        <translation>&amp;Amgryptio'r waled...</translation>
    </message>
    <message>
        <source>&amp;Change Passphrase...</source>
        <translation>&amp;Newid cyfrinymadrodd...</translation>
    </message>
    <message>
        <source>&amp;Sending addresses...</source>
        <translation>&amp;Cyfeiriadau anfon...</translation>
    </message>
    <message>
        <source>&amp;Receiving addresses...</source>
        <translation>&amp;Cyfeiriadau derbyn...</translation>
    </message>
    <message>
        <source>Open &amp;URI...</source>
        <translation>Agor &amp;URI...</translation>
    </message>
    <message>
        <source>Change the passphrase used for wallet encryption</source>
        <translation>Newid y cyfrinymadrodd a ddefnyddiwyd ar gyfer amgryptio'r waled</translation>
    </message>
    <message>
        <source>Bitcoin</source>
        <translation>Bitcoin</translation>
    </message>
    <message>
        <source>Wallet</source>
        <translation>Waled</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation>&amp;Anfon</translation>
    </message>
    <message>
        <source>&amp;Receive</source>
        <translation>&amp;Derbyn</translation>
    </message>
    <message>
        <source>&amp;Show / Hide</source>
        <translation>&amp;Dangos / Cuddio</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Ffeil</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Gosodiadau</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Cymorth</translation>
    </message>
    <message>
        <source>Tabs toolbar</source>
        <translation>Bar offer tabiau</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Gwall</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Rhybudd</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Gwybodaeth</translation>
    </message>
    <message>
        <source>Up to date</source>
        <translation>Cyfamserol</translation>
    </message>
    <message>
        <source>Catching up...</source>
        <translation>Dal i fyny</translation>
    </message>
    <message>
        <source>Date: %1
</source>
        <translation>Dyddiad: %1
</translation>
    </message>
    <message>
        <source>Type: %1
</source>
        <translation>Math: %1
</translation>
    </message>
    <message>
        <source>Label: %1
</source>
        <translation>Label: %1
</translation>
    </message>
    <message>
        <source>Address: %1
</source>
        <translation>Cyfeiriad: %1
</translation>
    </message>
    <message>
        <source>Sent transaction</source>
        <translation>Trafodiad a anfonwyd</translation>
    </message>
    <message>
        <source>Incoming transaction</source>
        <translation>Trafodiad sy'n cyrraedd</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;unlocked&lt;/b&gt;</source>
        <translation>Mae'r waled &lt;b&gt;wedi'i amgryptio&lt;/b&gt; ac &lt;b&gt;heb ei gloi&lt;/b&gt; ar hyn o bryd</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;locked&lt;/b&gt;</source>
        <translation>Mae'r waled &lt;b&gt;wedi'i amgryptio&lt;/b&gt; ac &lt;b&gt;ar glo&lt;/b&gt; ar hyn o bryd</translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Amount:</source>
        <translation>Maint</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Dyddiad</translation>
    </message>
    </context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>Edit Address</source>
        <translation>Golygu'r cyfeiriad</translation>
    </message>
    <message>
        <source>&amp;Label</source>
        <translation>&amp;Label</translation>
    </message>
    <message>
        <source>&amp;Address</source>
        <translation>&amp;Cyfeiriad</translation>
    </message>
    </context>
<context>
    <name>FreespaceChecker</name>
    <message>
        <source>name</source>
        <translation>enw</translation>
    </message>
    </context>
<context>
    <name>HelpMessageDialog</name>
    <message>
        <source>Usage:</source>
        <translation>Cynefod:</translation>
    </message>
    </context>
<context>
    <name>Intro</name>
    <message>
        <source>Welcome</source>
        <translation>Croeso</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Gwall</translation>
    </message>
    </context>
<context>
    <name>ModalOverlay</name>
    <message>
        <source>Form</source>
        <translation>Ffurflen</translation>
    </message>
    </context>
<context>
    <name>OpenURIDialog</name>
    <message>
        <source>Open URI</source>
        <translation>Agor URI</translation>
    </message>
    <message>
        <source>URI:</source>
        <translation>URI:</translation>
    </message>
    </context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation>Opsiynau</translation>
    </message>
    <message>
        <source>&amp;Network</source>
        <translation>&amp;Rhwydwaith</translation>
    </message>
    <message>
        <source>W&amp;allet</source>
        <translation>W&amp;aled</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Tor</source>
        <translation>Tor</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Ffenestr</translation>
    </message>
    <message>
        <source>&amp;Display</source>
        <translation>&amp;Dangos</translation>
    </message>
    </context>
<context>
    <name>OverviewPage</name>
    <message>
        <source>Form</source>
        <translation>Ffurflen</translation>
    </message>
    </context>
<context>
    <name>PaymentServer</name>
    </context>
<context>
    <name>PeerTableModel</name>
    </context>
<context>
    <name>QObject</name>
    <message>
        <source>%1 and %2</source>
        <translation>%1 a %2</translation>
    </message>
    </context>
<context>
    <name>QObject::QObject</name>
    </context>
<context>
    <name>QRImageWidget</name>
    </context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>&amp;Information</source>
        <translation>Gwybodaeth</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Rhwydwaith</translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation>&amp;Agor</translation>
    </message>
    </context>
<context>
    <name>ReceiveCoinsDialog</name>
    <message>
        <source>&amp;Label:</source>
        <translation>&amp;Label:</translation>
    </message>
    </context>
<context>
    <name>ReceiveRequestDialog</name>
    <message>
        <source>Copy &amp;Address</source>
        <translation>&amp;Cyfeiriad Copi</translation>
    </message>
    </context>
<context>
    <name>RecentRequestsTableModel</name>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Send Coins</source>
        <translation>Anfon arian</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Maint</translation>
    </message>
    <message>
        <source>Send to multiple recipients at once</source>
        <translation>Anfon at pobl lluosog ar yr un pryd</translation>
    </message>
    <message>
        <source>Balance:</source>
        <translation>Gweddill:</translation>
    </message>
    <message>
        <source>Confirm the send action</source>
        <translation>Cadarnhau'r gweithrediad anfon</translation>
    </message>
    </context>
<context>
    <name>SendCoinsEntry</name>
    <message>
        <source>A&amp;mount:</source>
        <translation>&amp;Maint</translation>
    </message>
    <message>
        <source>&amp;Label:</source>
        <translation>&amp;Label:</translation>
    </message>
    <message>
        <source>Alt+A</source>
        <translation>Alt+A</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation>Gludo cyfeiriad o'r glipfwrdd</translation>
    </message>
    <message>
        <source>Alt+P</source>
        <translation>Alt+P</translation>
    </message>
    <message>
        <source>Message:</source>
        <translation>Neges:</translation>
    </message>
    </context>
<context>
    <name>SendConfirmationDialog</name>
    </context>
<context>
    <name>ShutdownWindow</name>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    <message>
        <source>Alt+A</source>
        <translation>Alt+A</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation>Gludo cyfeiriad o'r glipfwrdd</translation>
    </message>
    <message>
        <source>Alt+P</source>
        <translation>Alt+P</translation>
    </message>
    </context>
<context>
    <name>SplashScreen</name>
    <message>
        <source>[testnet]</source>
        <translation>[testnet]</translation>
    </message>
</context>
<context>
    <name>TrafficGraphWidget</name>
    </context>
<context>
    <name>TransactionDesc</name>
    </context>
<context>
    <name>TransactionDescDialog</name>
    </context>
<context>
    <name>TransactionTableModel</name>
    </context>
<context>
    <name>TransactionView</name>
    </context>
<context>
    <name>UnitDisplayStatusBarControl</name>
    </context>
<context>
    <name>WalletFrame</name>
    </context>
<context>
    <name>WalletModel</name>
    </context>
<context>
    <name>WalletView</name>
    </context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>Options:</source>
        <translation>Opsiynau:</translation>
    </message>
    <message>
        <source>Bitcoin Core</source>
        <translation>Craidd Bitcoin</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Gwybodaeth</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Rhybudd</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Gwall</translation>
    </message>
</context>
</TS>

==> bitcoin-0.15.1.tar.gz: bitcoin-0.15.1/src/qt/locale/bitcoin_cy.ts <==
<TS language="cy" version="2.1">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Create a new address</source>
        <translation>Creu cyfeiriad newydd</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Newydd</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>Copio'r cyfeiriad sydd wedi'i ddewis i'r clipfwrdd system</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;Copïo</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation>C&amp;au</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation>&amp;Allforio</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Dileu</translation>
    </message>
    <message>
        <source>Sending addresses</source>
        <translation>Anfon cyfeiriadau</translation>
    </message>
    <message>
        <source>Receiving addresses</source>
        <translation>Derbyn cyfeiriadau</translation>
    </message>
    <message>
        <source>&amp;Copy Address</source>
        <translation>&amp;Copïo Cyfeiriad</translation>
    </message>
    <message>
        <source>Copy &amp;Label</source>
        <translation>Copïo &amp;Label</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation>Methu Allforio</translation>
    </message>
    </context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation>Label</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Cyfeiriad</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(dim label)</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Enter passphrase</source>
        <translation>Teipiwch gyfrinymadrodd</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation>Cyfrinymadrodd newydd</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation>Ailadroddwch gyfrinymadrodd newydd</translation>
    </message>
    </context>
<context>
    <name>BanTableModel</name>
    </context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>Synchronizing with network...</source>
        <translation>Cysoni â'r rhwydwaith...</translation>
    </message>
    <message>
        <source>&amp;Overview</source>
        <translation>&amp;Trosolwg</translation>
    </message>
    <message>
        <source>Show general overview of wallet</source>
        <translation>Dangos trosolwg cyffredinol y waled</translation>
    </message>
    <message>
        <source>&amp;Transactions</source>
        <translation>&amp;Trafodion</translation>
    </message>
    <message>
        <source>Browse transaction history</source>
        <translation>Pori hanes trafodion</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>A&amp;llanfa</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation>Gadael rhaglen</translation>
    </message>
    <message>
        <source>&amp;About %1</source>
        <translation>&amp;Ynghylch %1</translation>
    </message>
    <message>
        <source>Show information about %1</source>
        <translation>Dangos gwybodaeth am %1</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Ynghylch &amp;Qt</translation>
    </message>
    <message>
        <source>&amp;Options...</source>
        <translation>&amp;Opsiynau</translation>
    </message>
    <message>
        <source>&amp;Encrypt Wallet...</source>
        <translation>&amp;Amgryptio'r waled...</translation>
    </message>
    <message>
        <source>&amp;Change Passphrase...</source>
        <translation>&amp;Newid cyfrinymadrodd...</translation>
    </message>
    <message>
        <source>&amp;Sending addresses...</source>
        <translation>&amp;Cyfeiriadau anfon...</translation>
    </message>
    <message>
        <source>&amp;Receiving addresses...</source>
        <translation>&amp;Cyfeiriadau derbyn...</translation>
    </message>
    <message>
        <source>Open &amp;URI...</source>
        <translation>Agor &amp;URI...</translation>
    </message>
    <message>
        <source>Change the passphrase used for wallet encryption</source>
        <translation>Newid y cyfrinymadrodd a ddefnyddiwyd ar gyfer amgryptio'r waled</translation>
    </message>
    <message>
        <source>Bitcoin</source>
        <translation>Bitcoin</translation>
    </message>
    <message>
        <source>Wallet</source>
        <translation>Waled</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation>&amp;Anfon</translation>
    </message>
    <message>
        <source>&amp;Receive</source>
        <translation>&amp;Derbyn</translation>
    </message>
    <message>
        <source>&amp;Show / Hide</source>
        <translation>&amp;Dangos / Cuddio</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Ffeil</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Gosodiadau</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Cymorth</translation>
    </message>
    <message>
        <source>Tabs toolbar</source>
        <translation>Bar offer tabiau</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Gwall</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Rhybudd</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Gwybodaeth</translation>
    </message>
    <message>
        <source>Up to date</source>
        <translation>Cyfamserol</translation>
    </message>
    <message>
        <source>Catching up...</source>
        <translation>Dal i fyny</translation>
    </message>
    <message>
        <source>Date: %1
</source>
        <translation>Dyddiad: %1
</translation>
    </message>
    <message>
        <source>Type: %1
</source>
        <translation>Math: %1
</translation>
    </message>
    <message>
        <source>Label: %1
</source>
        <translation>Label: %1
</translation>
    </message>
    <message>
        <source>Address: %1
</source>
        <translation>Cyfeiriad: %1
</translation>
    </message>
    <message>
        <source>Sent transaction</source>
        <translation>Trafodiad a anfonwyd</translation>
    </message>
    <message>
        <source>Incoming transaction</source>
        <translation>Trafodiad sy'n cyrraedd</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;unlocked&lt;/b&gt;</source>
        <translation>Mae'r waled &lt;b&gt;wedi'i amgryptio&lt;/b&gt; ac &lt;b&gt;heb ei gloi&lt;/b&gt; ar hyn o bryd</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;locked&lt;/b&gt;</source>
        <translation>Mae'r waled &lt;b&gt;wedi'i amgryptio&lt;/b&gt; ac &lt;b&gt;ar glo&lt;/b&gt; ar hyn o bryd</translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Amount:</source>
        <translation>Maint</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Dyddiad</translation>
    </message>
    <message>
        <source>Copy address</source>
        <translation>Copïo cyfeiriad</translation>
    </message>
    <message>
        <source>Copy label</source>
        <translation>Copïo label</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(dim label)</translation>
    </message>
    </context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>Edit Address</source>
        <translation>Golygu'r cyfeiriad</translation>
    </message>
    <message>
        <source>&amp;Label</source>
        <translation>&amp;Label</translation>
    </message>
    <message>
        <source>&amp;Address</source>
        <translation>&amp;Cyfeiriad</translation>
    </message>
    </context>
<context>
    <name>FreespaceChecker</name>
    <message>
        <source>name</source>
        <translation>enw</translation>
    </message>
    </context>
<context>
    <name>HelpMessageDialog</name>
    <message>
        <source>Usage:</source>
        <translation>Cynefod:</translation>
    </message>
    </context>
<context>
    <name>Intro</name>
    <message>
        <source>Welcome</source>
        <translation>Croeso</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Gwall</translation>
    </message>
    </context>
<context>
    <name>ModalOverlay</name>
    <message>
        <source>Form</source>
        <translation>Ffurflen</translation>
    </message>
    </context>
<context>
    <name>OpenURIDialog</name>
    <message>
        <source>Open URI</source>
        <translation>Agor URI</translation>
    </message>
    <message>
        <source>URI:</source>
        <translation>URI:</translation>
    </message>
    </context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation>Opsiynau</translation>
    </message>
    <message>
        <source>&amp;Network</source>
        <translation>&amp;Rhwydwaith</translation>
    </message>
    <message>
        <source>W&amp;allet</source>
        <translation>W&amp;aled</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Tor</source>
        <translation>Tor</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Ffenestr</translation>
    </message>
    <message>
        <source>&amp;Display</source>
        <translation>&amp;Dangos</translation>
    </message>
    </context>
<context>
    <name>OverviewPage</name>
    <message>
        <source>Form</source>
        <translation>Ffurflen</translation>
    </message>
    </context>
<context>
    <name>PaymentServer</name>
    </context>
<context>
    <name>PeerTableModel</name>
    </context>
<context>
    <name>QObject</name>
    <message>
        <source>%1 and %2</source>
        <translation>%1 a %2</translation>
    </message>
    </context>
<context>
    <name>QObject::QObject</name>
    </context>
<context>
    <name>QRImageWidget</name>
    </context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>&amp;Information</source>
        <translation>Gwybodaeth</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Rhwydwaith</translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation>&amp;Agor</translation>
    </message>
    </context>
<context>
    <name>ReceiveCoinsDialog</name>
    <message>
        <source>&amp;Label:</source>
        <translation>&amp;Label:</translation>
    </message>
    <message>
        <source>Copy label</source>
        <translation>Copïo label</translation>
    </message>
    </context>
<context>
    <name>ReceiveRequestDialog</name>
    <message>
        <source>Copy &amp;Address</source>
        <translation>&amp;Cyfeiriad Copi</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Cyfeiriad</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Label</translation>
    </message>
    </context>
<context>
    <name>RecentRequestsTableModel</name>
    <message>
        <source>Date</source>
        <translation>Dyddiad</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Label</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(dim label)</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Send Coins</source>
        <translation>Anfon arian</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Maint</translation>
    </message>
    <message>
        <source>Send to multiple recipients at once</source>
        <translation>Anfon at pobl lluosog ar yr un pryd</translation>
    </message>
    <message>
        <source>Balance:</source>
        <translation>Gweddill:</translation>
    </message>
    <message>
        <source>Confirm the send action</source>
        <translation>Cadarnhau'r gweithrediad anfon</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(dim label)</translation>
    </message>
</context>
<context>
    <name>SendCoinsEntry</name>
    <message>
        <source>A&amp;mount:</source>
        <translation>&amp;Maint</translation>
    </message>
    <message>
        <source>&amp;Label:</source>
        <translation>&amp;Label:</translation>
    </message>
    <message>
        <source>Alt+A</source>
        <translation>Alt+A</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation>Gludo cyfeiriad o'r glipfwrdd</translation>
    </message>
    <message>
        <source>Alt+P</source>
        <translation>Alt+P</translation>
    </message>
    <message>
        <source>Message:</source>
        <translation>Neges:</translation>
    </message>
    </context>
<context>
    <name>SendConfirmationDialog</name>
    </context>
<context>
    <name>ShutdownWindow</name>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    <message>
        <source>Alt+A</source>
        <translation>Alt+A</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation>Gludo cyfeiriad o'r glipfwrdd</translation>
    </message>
    <message>
        <source>Alt+P</source>
        <translation>Alt+P</translation>
    </message>
    </context>
<context>
    <name>SplashScreen</name>
    <message>
        <source>[testnet]</source>
        <translation>[testnet]</translation>
    </message>
</context>
<context>
    <name>TrafficGraphWidget</name>
    </context>
<context>
    <name>TransactionDesc</name>
    <message>
        <source>Date</source>
        <translation>Dyddiad</translation>
    </message>
    </context>
<context>
    <name>TransactionDescDialog</name>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Date</source>
        <translation>Dyddiad</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Math</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Label</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(dim label)</translation>
    </message>
    </context>
<context>
    <name>TransactionView</name>
    <message>
        <source>Today</source>
        <translation>Heddiw</translation>
    </message>
    <message>
        <source>This week</source>
        <translation>Yr wythnos hon</translation>
    </message>
    <message>
        <source>This month</source>
        <translation>Y mis hwn</translation>
    </message>
    <message>
        <source>Last month</source>
        <translation>Mis diwethaf</translation>
    </message>
    <message>
        <source>This year</source>
        <translation>Eleni</translation>
    </message>
    <message>
        <source>Copy address</source>
        <translation>Copïo cyfeiriad</translation>
    </message>
    <message>
        <source>Copy label</source>
        <translation>Copïo label</translation>
    </message>
    <message>
        <source>Edit label</source>
        <translation>Golygu label</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Dyddiad</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Math</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Label</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Cyfeiriad</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation>Methu Allforio</translation>
    </message>
    </context>
<context>
    <name>UnitDisplayStatusBarControl</name>
    </context>
<context>
    <name>WalletFrame</name>
    </context>
<context>
    <name>WalletModel</name>
    </context>
<context>
    <name>WalletView</name>
    <message>
        <source>&amp;Export</source>
        <translation>&amp;Allforio</translation>
    </message>
    </context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>Options:</source>
        <translation>Opsiynau:</translation>
    </message>
    <message>
        <source>Bitcoin Core</source>
        <translation>Craidd Bitcoin</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Gwybodaeth</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Rhybudd</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Gwall</translation>
    </message>
</context>
</TS>
